@@ -7,20 +7,19 @@
 #'
 #' @param gl -- name of the genlight object containing the SNP data [required]
 #' @param method -- breakdown variable [default pop(x)]
-#' @param stats -- statistic to calculate: mean [only mean(x)/2 currently implemented]
+#' @param stat -- statistic to calculate: mean [only mean(x)/2 currently implemented]
 #' @return A matrix, populations (rows) by loci (columns), showing the statistic [mean/2]
-#' @export
 #' @author Arthur Georges (glbugs@aerg.canberra.edu.au)
 #' @examples
-#' result <- gl.gene.freq(testset.gl, method=pop(gl), stat="mean")
+#' result <- dartR:::gl.gene.freq(testset.gl, method=pop(gl), stat="mean")
 
-gl.gene.freq <- function(gl, method=pop(gl), stats="mean") {
+gl.gene.freq <- function(gl, method=pop(gl), stat="mean") {
   
   # For each column of gl, apply the function tapply with index variable pop(gl)and function mean(x)/2
-  if (stats=="mean"){
+  if (stat=="mean"){
     t=apply(as.matrix(gl),2, tapply, pop(gl), function(x){mean(x, na.rm=TRUE)/2}) 
   } else {
-    cat("Only stats=\"mean\" is implemented\n"); stop()
+    cat("Only stat=\"mean\" is implemented\n"); stop()
   }
   return(t)
 } 
